@@ -183,6 +183,61 @@ func Test_Cataloger_PositiveCases(t *testing.T) {
 				Metadata:  metadata("mariadb-binary"),
 			},
 		},
+		{
+			logicalFixture: "mongodb/8.0.17/linux-amd64",
+			expected: pkg.Package{
+				Name:      "mongodb",
+				Version:   "8.0.17",
+				Type:      "binary",
+				PURL:      "pkg:generic/mongodb@8.0.17",
+				Locations: locations("mongod"),
+				Metadata:  metadata("mongodb-binary"),
+			},
+		},
+		{
+			logicalFixture: "mongodb/7.0.28/linux-amd64",
+			expected: pkg.Package{
+				Name:      "mongodb",
+				Version:   "7.0.28",
+				Type:      "binary",
+				PURL:      "pkg:generic/mongodb@7.0.28",
+				Locations: locations("mongod"),
+				Metadata:  metadata("mongodb-binary"),
+			},
+		},
+		{
+			logicalFixture: "mongodb/6.0.27/linux-amd64",
+			expected: pkg.Package{
+				Name:      "mongodb",
+				Version:   "6.0.27",
+				Type:      "binary",
+				PURL:      "pkg:generic/mongodb@6.0.27",
+				Locations: locations("mongod"),
+				Metadata:  metadata("mongodb-binary"),
+			},
+		},
+		{
+			logicalFixture: "mongodb/5.0.32/linux-amd64",
+			expected: pkg.Package{
+				Name:      "mongodb",
+				Version:   "5.0.32",
+				Type:      "binary",
+				PURL:      "pkg:generic/mongodb@5.0.32",
+				Locations: locations("mongod"),
+				Metadata:  metadata("mongodb-binary"),
+			},
+		},
+		{
+			logicalFixture: "mongodb/4.4.30/linux-amd64",
+			expected: pkg.Package{
+				Name:      "mongodb",
+				Version:   "4.4.30",
+				Type:      "binary",
+				PURL:      "pkg:generic/mongodb@4.4.30",
+				Locations: locations("mongod"),
+				Metadata:  metadata("mongodb-binary"),
+			},
+		},
 		{
 			logicalFixture: "traefik/1.7.34/linux-amd64",
 			expected: pkg.Package{
@@ -227,6 +282,17 @@ func Test_Cataloger_PositiveCases(t *testing.T) {
 				Metadata:  metadata("traefik-binary"),
 			},
 		},
+		{
+			logicalFixture: "traefik/3.6.5/linux-amd64",
+			expected: pkg.Package{
+				Name:      "traefik",
+				Version:   "3.6.5",
+				Type:      "binary",
+				PURL:      "pkg:generic/traefik@3.6.5",
+				Locations: locations("traefik"),
+				Metadata:  metadata("traefik-binary"),
+			},
+		},
 		{
 			logicalFixture: "memcached/1.6.18/linux-amd64",
 			expected: pkg.Package{
@@ -469,6 +535,17 @@ func Test_Cataloger_PositiveCases(t *testing.T) {
 				Metadata:  metadata("redis-binary"),
 			},
 		},
+		{
+			logicalFixture: "valkey-server/9.0.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "valkey",
+				Version:   "9.0.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/valkey@9.0.0",
+				Locations: locations("valkey-server"),
+				Metadata:  metadata("valkey-binary"),
+			},
+		},
 		{
 			logicalFixture: "python-shared-lib/3.7.4/linux-amd64",
 			expected: pkg.Package{
@@ -1419,6 +1496,270 @@ func Test_Cataloger_PositiveCases(t *testing.T) {
 				},
 			},
 		},
+		{
+			logicalFixture: "istio_pilot-discovery/1.26.8/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-discovery",
+				Version:   "1.26.8",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.26.8",
+				Locations: locations("pilot-discovery"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "istio_pilot-discovery/1.8.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-discovery",
+				Version:   "1.8.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.8.0",
+				Locations: locations("pilot-discovery"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "istio_pilot-discovery/1.3.8/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-discovery",
+				Version:   "1.3.8",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.3.8",
+				Locations: locations("pilot-discovery"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "istio_pilot-discovery/1.1.17/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-discovery",
+				Version:   "1.1.17",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.1.17",
+				Locations: locations("pilot-discovery"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "istio_pilot-agent/1.26.8/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-agent",
+				Version:   "1.26.8",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.26.8",
+				Locations: locations("pilot-agent"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "istio_pilot-agent/1.8.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-agent",
+				Version:   "1.8.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.8.0",
+				Locations: locations("pilot-agent"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "istio_pilot-agent/1.1.17/linux-amd64",
+			expected: pkg.Package{
+				Name:      "pilot-agent",
+				Version:   "1.1.17",
+				Type:      "binary",
+				PURL:      "pkg:generic/istio@1.1.17",
+				Locations: locations("pilot-agent"),
+				Metadata:  metadata("istio-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/12.3.1/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "12.3.1",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@12.3.1",
+				Locations: locations("grafana"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/12.0.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "12.0.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@12.0.0",
+				Locations: locations("grafana"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/11.0.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "11.0.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@11.0.0",
+				Locations: locations("grafana"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/10.4.19/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "10.4.19",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@10.4.19",
+				Locations: locations("grafana"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/9.5.21/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "9.5.21",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@9.5.21",
+				Locations: locations("grafana"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/9.0.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "9.0.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@9.0.0",
+				Locations: locations("grafana-server"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/7.5.17/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "7.5.17",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@7.5.17",
+				Locations: locations("grafana-server"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "grafana/6.7.6/linux-amd64",
+			expected: pkg.Package{
+				Name:      "grafana",
+				Version:   "6.7.6",
+				Type:      "binary",
+				PURL:      "pkg:generic/grafana@6.7.6",
+				Locations: locations("grafana-server"),
+				Metadata:  metadata("grafana-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.36.4/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.36.4",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.36.4",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.34.5/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.34.5",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.34.5",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.28.7/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.28.7",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.28.7",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.22.11/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.22.11",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.22.11",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.20.7/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.20.7",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.20.7",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.18.6/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.18.6-dev",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.18.6-dev",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.14.3/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.14.3",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.14.3",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.11.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.11.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.11.0",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
+		{
+			logicalFixture: "envoy/1.6.0/linux-amd64",
+			expected: pkg.Package{
+				Name:      "envoy",
+				Version:   "1.6.0",
+				Type:      "binary",
+				PURL:      "pkg:generic/envoy@1.6.0",
+				Locations: locations("envoy"),
+				Metadata:  metadata("envoy-binary"),
+			},
+		},
 	}
 
 	for _, test := range tests {
